;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "hare-mode" "20251002.1915"
  "Hare mode."
  '((emacs "25.1"))
  :url "https://git.sr.ht/~grafov/hare-mode"
  :commit "bd7e2e8b1437a45b60d6dc053ef26f47ec1436db"
  :revdesc "bd7e2e8b1437"
  :keywords '("languages")
  :authors '(("Benjamín Buccianti" . "benjamin@buccianti.dev")
             ("Amin Bandali" . "bandali@gnu.org")
             ("Theodor Thornhill" . "theo@thornhill.no")
             ("Sebastian" . "sebastian@sebsite.pw")
             ("Alexander Grafov" . "grafov@inet.name"))
  :maintainers '(("Benjamín Buccianti" . "benjamin@buccianti.dev")
                 ("Amin Bandali" . "bandali@gnu.org")
                 ("Theodor Thornhill" . "theo@thornhill.no")
                 ("Sebastian" . "sebastian@sebsite.pw")
                 ("Alexander Grafov" . "grafov@inet.name")))
